'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _events = require('events');

var _events2 = _interopRequireDefault(_events);

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class FluxStore {
    constructor(_key, _fluxContext, _fluxController) {
        this.data = null;
        this.key = _key;
        this.id = _key;
        this.fluxContext = _fluxContext;
        this.fluxController = _fluxController;
        this.eventEmitter = new _events2.default.EventEmitter();

        if (typeof window !== 'undefined' && window.fluxStores && window.fluxStores[_key]) {
            const obj = window.fluxStores[_key];
            this.updateData(_immutable2.default.fromJS(obj), true);
        }

        return this;
    }

    emit(event) {
        this.eventEmitter.emit(event);
    }

    addListener(event, listener) {
        //console.log('Adding listener: ', event, listener);
        this.eventEmitter.addListener(event, listener);
    }

    removeListener(event, listener) {
        //console.log('Removing listener: ', event, listener);
        this.eventEmitter.removeListener(event, listener);
    }

    emitUpdate(event) {
        if (event) {
            this.emit(`UPDATE:${ event }`);
        }

        this.emit('update', event);
    }

    addUpdateListener(listener) {
        this.addListener('update', listener);
    }

    removeUpdateListener(listener) {
        this.removeListener('update', listener);
    }

    updateData(data, event, noEmit) {
        this.data = data;

        if (!noEmit) {
            this.emitUpdate(event);
        }

        return this;
    }

    _render() {
        return this.data && this.data.toJS();
    }
}
exports.default = FluxStore;